==> jc-1.4.0.tar.gz: soot/toolkits/scalar/FastColorer__24UnitInterferenceGraph.h <==
// public class soot.toolkits.scalar.FastColorer$UnitInterferenceGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 79cf99b72c7e5b36 soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_
#define _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Local$object;
struct _jc_soot_toolkits_scalar_LiveLocals$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object;

typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable;
typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *);
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$_init$ffc50b993ca0823b(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern _jc_object_array *_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$getInterferencesOf$df927e6d19717ff8(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$getLocals$678b477fe4f9c09c(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *);
extern jboolean _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *);
extern jboolean _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$localsInterfere$1b0efbc2f9b00e42(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$setInterference$b9cd541f1e7551f0(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$getInterferencesOf$df927e6d19717ff8;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$getLocals$678b477fe4f9c09c;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$localsInterfere$1b0efbc2f9b00e42;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$setInterference$b9cd541f1e7551f0;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods {
	_jc_object_array	*(*getInterferencesOf$df927e6d19717ff8)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *);
	struct _jc_object	*(*getLocals$678b477fe4f9c09c)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *);
	jboolean	(*localsInterfere$1b0efbc2f9b00e42)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *);
	void	(*setInterference$b9cd541f1e7551f0)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
};

// Vtype
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs {
	struct _jc_object	*localToLocals;
	struct _jc_object	*locals;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs {
    _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object {
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype	*vtype;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$class_object;

#endif	/* _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/FastColorer__24UnitInterferenceGraph.h <==
// public class soot.toolkits.scalar.FastColorer$UnitInterferenceGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 79cf99b72c7e5b36 soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_
#define _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Local$object;
struct _jc_soot_toolkits_scalar_LiveLocals$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object;

typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable;
typedef const struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$_init$ffc50b993ca0823b(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_soot_Body$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$getInterferencesOf$df927e6d19717ff8(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$getLocals$678b477fe4f9c09c(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$localsInterfere$1b0efbc2f9b00e42(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method$setInterference$b9cd541f1e7551f0(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$getInterferencesOf$df927e6d19717ff8;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$getLocals$678b477fe4f9c09c;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$localsInterfere$1b0efbc2f9b00e42;
extern _jc_method _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$method_info$setInterference$b9cd541f1e7551f0;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods {
	_jc_object_array	*(*getInterferencesOf$df927e6d19717ff8)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLocals$678b477fe4f9c09c)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *) _JC_JCNI_ATTR;
	jboolean	(*localsInterfere$1b0efbc2f9b00e42)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setInterference$b9cd541f1e7551f0)(_jc_env *, struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vmethods	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
};

// Vtype
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs {
	struct _jc_object	*localToLocals;
	struct _jc_object	*locals;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs {
    _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_refs	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$sub_nonrefs	soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$object {
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype	*vtype;
	_jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$vtype _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph$class_object;

#endif	/* _JC_soot_toolkits_scalar_FastColorer__24UnitInterferenceGraph_H_ */
